@@ -1,6 +1,6 @@
 from .conf import Config, ConfigDefaultTypesMixin
 from .connection import Request, WebSocket
-from .context import ExecutionContext
+from .context import ExecutionContext, HostContext, IExecutionContext, IHostContext
 from .controller import ControllerBase
 from .factory import AppFactory
 from .guard import BaseAPIKey, BaseAuthGuard, BaseHttpAuth, GuardCanActivate
@@ -26,6 +26,9 @@ __all__ = [
     "render_template",
     "render_template_string",
     "ExecutionContext",
+    "IExecutionContext",
+    "IHostContext",
+    "HostContext",
     "ControllerBase",
     "ConfigDefaultTypesMixin",
     "ModuleBase",
