@@ -1,8 +1,5 @@
-import sys
-
 from starlette.middleware import Middleware as Middleware
 from starlette.middleware.authentication import AuthenticationMiddleware
-from starlette.middleware.base import BaseHTTPMiddleware
 from starlette.middleware.cors import CORSMiddleware as CORSMiddleware
 from starlette.middleware.errors import ServerErrorMiddleware
 from starlette.middleware.gzip import GZipMiddleware as GZipMiddleware
@@ -15,18 +12,14 @@ from starlette.middleware.trustedhost import (
 from starlette.middleware.wsgi import WSGIMiddleware as WSGIMiddleware
 
 from .di import RequestServiceProviderMiddleware
+from .exceptions import ExceptionMiddleware
+from .function import FunctionBasedMiddleware
 from .versioning import RequestVersioningMiddleware
 
-if sys.version_info >= (3, 7):  # pragma: no cover
-    from starlette.middleware.exceptions import ExceptionMiddleware
-else:
-    from starlette.exceptions import ExceptionMiddleware  # type:ignore
-
-
 __all__ = [
     "Middleware",
     "AuthenticationMiddleware",
-    "BaseHTTPMiddleware",
+    "FunctionBasedMiddleware",
     "CORSMiddleware",
     "ServerErrorMiddleware",
     "ExceptionMiddleware",
