@@ -1,13 +1,14 @@
 import typing as t
 
 from starlette.middleware import Middleware
-from starlette.middleware.base import BaseHTTPMiddleware
 
 from ellar.core.schema import Schema
 
+from .function import FunctionBasedMiddleware
+
 
 class MiddlewareSchema(Schema):
-    middleware_class: t.Type[BaseHTTPMiddleware]
+    middleware_class: t.Type[FunctionBasedMiddleware]
     dispatch: t.Callable[[t.Any, t.Callable], t.Any]
     options: t.Dict
 
