@@ -16,7 +16,7 @@ from starlette.exceptions import HTTPException
 from ellar.constants import sequence_shape_to_type, sequence_shapes, sequence_types
 from ellar.core.context import IExecutionContext
 from ellar.core.datastructures import UploadFile
-from ellar.exceptions import RequestValidationError
+from ellar.core.exceptions import RequestValidationError
 from ellar.logger import logger
 from ellar.types import T
 
@@ -73,7 +73,7 @@ class HeaderParameterResolver(RouteParameterResolver):
     def get_received_parameter(
         cls, ctx: IExecutionContext
     ) -> t.Union[QueryParams, Headers]:
-        connection = ctx.switch_to_http_connection()
+        connection = ctx.switch_to_http_connection().get_client()
         return connection.headers
 
     async def resolve_handle(
@@ -116,14 +116,14 @@ class QueryParameterResolver(HeaderParameterResolver):
     def get_received_parameter(
         cls, ctx: IExecutionContext
     ) -> t.Union[QueryParams, Headers]:
-        connection = ctx.switch_to_http_connection()
+        connection = ctx.switch_to_http_connection().get_client()
         return connection.query_params
 
 
 class PathParameterResolver(RouteParameterResolver):
     @classmethod
     def get_received_parameter(cls, ctx: IExecutionContext) -> t.Mapping[str, t.Any]:
-        connection = ctx.switch_to_http_connection()
+        connection = ctx.switch_to_http_connection().get_client()
         return connection.path_params
 
     async def resolve_handle(self, ctx: IExecutionContext, **kwargs: t.Any) -> t.Tuple:
@@ -142,7 +142,7 @@ class PathParameterResolver(RouteParameterResolver):
 class CookieParameterResolver(PathParameterResolver):
     @classmethod
     def get_received_parameter(cls, ctx: IExecutionContext) -> t.Mapping[str, t.Any]:
-        connection = ctx.switch_to_http_connection()
+        connection = ctx.switch_to_http_connection().get_client()
         return connection.cookies
 
 
@@ -171,7 +171,7 @@ class BodyParameterResolver(WsBodyParameterResolver):
 
     async def get_request_body(self, ctx: IExecutionContext) -> t.Any:
         try:
-            request = ctx.switch_to_request()
+            request = ctx.switch_to_http_connection().get_request()
             body_bytes = await request.body()
             if body_bytes:
                 json_body: t.Any = Undefined
@@ -218,7 +218,7 @@ class FormParameterResolver(BodyParameterResolver):
 
     async def get_request_body(self, ctx: IExecutionContext) -> t.Any:
         try:
-            request = ctx.switch_to_request()
+            request = ctx.switch_to_http_connection().get_request()
             body_bytes = await request.form()
             return body_bytes
         except Exception as e:
@@ -340,20 +340,57 @@ class BulkParameterResolver(RouteParameterResolver):
 
 
 class BulkFormParameterResolver(FormParameterResolver, BulkParameterResolver):
+    def __init__(self, *args: t.Any, is_grouped: bool = False, **kwargs: t.Any):
+        super().__init__(*args, **kwargs)
+        self.is_grouped = is_grouped
+        self._use_resolver: t.Callable[
+            [IExecutionContext, t.Any], t.Awaitable[t.Tuple]
+        ] = t.cast(
+            t.Callable[[IExecutionContext, t.Any], t.Awaitable[t.Tuple]],
+            self.resolve_grouped_fields
+            if is_grouped
+            else self.resolve_ungrouped_fields,
+        )
+
+    async def resolve_grouped_fields(
+        self, ctx: IExecutionContext, body: t.Any
+    ) -> t.Tuple:
+        value, resolver_errors = await self._get_resolver_data(ctx, body)
+        if resolver_errors:
+            return value, resolver_errors
+
+        processed_value, processed_errors = self.model_field.validate(
+            value,
+            {},
+            loc=(self.model_field.field_info.in_.value, self.model_field.alias),
+        )
+        if processed_errors:
+            processed_errors = self.validate_error_sequence(processed_errors)
+            return processed_value, processed_errors
+        return {self.model_field.name: processed_value}, []
+
+    async def resolve_ungrouped_fields(
+        self, ctx: IExecutionContext, body: t.Any
+    ) -> t.Tuple:
+        return await self._get_resolver_data(ctx, body)
+
+    async def _get_resolver_data(self, ctx: IExecutionContext, body: t.Any) -> t.Tuple:
+        values: t.Dict[str, t.Any] = {}
+        errors: t.List[ErrorWrapper] = []
+        for parameter_resolver in self._resolvers:
+            value_, errors_ = await parameter_resolver.resolve(ctx=ctx, body=body)
+            if value_:
+                values.update(value_)
+            if errors_:
+                errors += self.validate_error_sequence(errors_)
+        return values, errors
+
     async def resolve_handle(
         self, ctx: IExecutionContext, *args: t.Any, **kwargs: t.Any
     ) -> t.Tuple:
         _body = await self.get_request_body(ctx)
-        values: t.Dict[str, t.Any] = {}
-        errors: t.List[ErrorWrapper] = []
         if self._resolvers:
-            for parameter_resolver in self._resolvers:
-                value_, errors_ = await parameter_resolver.resolve(ctx=ctx, body=_body)
-                if value_:
-                    values.update(value_)
-                if errors_:
-                    errors += self.validate_error_sequence(errors_)
-            return values, errors
+            return await self._use_resolver(ctx, _body)
         return await super(BulkFormParameterResolver, self).resolve_handle(
             ctx, *args, **kwargs
         )
@@ -374,6 +411,23 @@ class BulkBodyParameterResolver(BodyParameterResolver, BulkParameterResolver):
 
 
 class NonFieldRouteParameterResolver(BaseRouteParameterResolver, ABC):
+    """
+    Define extra route function parameter dependencies
+
+    Example:
+    >>> class UserField(NonFieldRouteParameterResolver):
+    >>>     async def resolve(self, ctx: IExecutionContext, **kwargs: t.Any) -> t.Any:
+    >>>          request = ctx.switch_to_http_connection().get_request()
+    >>>          user = request.get('user', None)
+    >>>          if user:
+    >>>             return {self.parameter_name: user}, []
+    >>>          return {}, [ErrorWrapper('Authenticated Users Only', loc=self.parameter_name)]
+    Usage:
+    >>> @get('/abc')
+    >>> def abc(user: User = UserField()):
+    >>>     return user
+    """
+
     in_: str = "non_field_parameter"
 
     def __init__(self, data: t.Optional[t.Any] = None):
@@ -391,6 +445,10 @@ class NonFieldRouteParameterResolver(BaseRouteParameterResolver, ABC):
 
 
 class ParameterInjectable(NonFieldRouteParameterResolver):
+    """
+    Defines `Provider` resolver for route parameter based on the provided `service`
+    """
+
     def __init__(self, service: t.Optional[t.Type[T]] = None) -> None:
         if service:
             assert isinstance(service, type), "Service must be a type"
@@ -429,3 +487,38 @@ class ParameterInjectable(NonFieldRouteParameterResolver):
         except Exception as ex:
             logger.error(f"Unable to resolve service {self.data} \nErrorMessage: {ex}")
             return {}, [ErrorWrapper(ex, loc=self.parameter_name or "provide")]
+
+
+class BaseRequestRouteParameterResolver(NonFieldRouteParameterResolver):
+    """
+    Defines HTTPConnection fields resolver for route parameter based on the provided `lookup_connection_field`
+    """
+
+    # Look up field in ctx.switch_to_connection().get_client().lookup_connection_field
+    lookup_connection_field: t.Optional[str]
+
+    def __call__(
+        self, parameter_name: str, parameter_annotation: t.Type[T]
+    ) -> "ParameterInjectable":
+        result = super().__call__(parameter_name, parameter_annotation)
+        if not hasattr(self, "lookup_connection_field"):
+            raise Exception(f"{self.__class__.__name__}.request_field is not set")
+        return result  # type: ignore
+
+    async def get_value(self, ctx: IExecutionContext) -> t.Any:
+        assert self.lookup_connection_field
+
+        connection = ctx.switch_to_http_connection().get_client()
+        return connection.get(self.lookup_connection_field)
+
+    async def resolve(
+        self, ctx: IExecutionContext, **kwargs: t.Any
+    ) -> t.Tuple[t.Dict, t.List]:
+        try:
+            value = await self.get_value(ctx)
+            return {self.parameter_name: value}, []
+        except Exception as ex:
+            logger.error(
+                f"Unable to resolve `{self.lookup_connection_field}` in connection \nErrorMessage: {ex}"
+            )
+            return {}, [ErrorWrapper(ex, loc=str(self.parameter_name))]
